---
title: "Reconcile Docker With Deutsche Bahn"
description: >
  If WiFi does not work on Deutsche Bahn's ICE trains and you have Docker installed,
  there may be network interference which can be fixed easily.
date: 2024-09-26T09:07:30Z
draft: false
# ShowLastmod: true
toc: false
scrolltotop: true
#featuredImg: reconcile-docker-with-deutsche-bahn.png
tags:
  - network
  - Deutsche Bahn
  - Docker
  - travel
---

![Composition of screenshots](reconcile-docker-with-deutsche-bahn.png)

If you happen to be a (Linux) power user travelling on a Deutsche Bahn [ICE
long-distance train][ice] and you wonder why you don't get a working network
connection with the complemenatary "WIFIonICE" wireless network, there may be a
network interference on your laptop.

There are multiple solutions for this on the web. My favorite solution is to
change Docker's network configuration by editing (or creating) the file
`/etc/docker/daemons.json`. However, you may need to prune existing Docker
networks first. Otherwise the Docker service will fail to start with the
following message:

```plain
failed to start daemon: Error initializing network controller: error creating default "bridge" network: all predefined address pools have been fully subnetted
```

Therefore, I recommend the following steps (this is on a Fedora Linux system with *systemd*):

1. Stop any docker containers that you may have running, including services managed by docker compose.
2. Prune the networks:

   ```bash
   docker network prune
   ```

3. Create or edit `/etc/docker/daemon.json` so that it contains the following:

   ```plain
   {
       "default-address-pools":
       [
           {"base":"172.19.0.0/16","size":24}
       ]
   }
   ```

4. Restart docker:

   ```bash
   systemctl restart docker
   ```

5. Connect to `WIFIonICE` and enjoy your network connection :-)

## References

- StackExchange answer that provides the solution as presented here -- see also
  the answer about pruning the networks below.

  <https://unix.stackexchange.com/a/539258/110635>

- If you don't want to or cannot configure your Docker networks, you can also
  turn Docker off and on again when you travel:

  <https://kuttler.eu/code/ice-wlan-linux-docker/>

  This is what I used to do myself, but nowadays I prefer to just configure the
  Docker network differently.

- There are many more internet sources (and I have just added another one...), I
  won't copy all those links into my post, see DuckDuckGo search results
  for yourself:

  <https://duckduckgo.com/?q=docker+wifi+on+ice>

[ice]: https://int.bahn.de/en/trains/long-distance-trains
